@@ -16,16 +16,19 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 """Dependency and Provenance graph building."""
+
 import functools
 import shutil
 import sys
 import traceback
 from collections import defaultdict
+from datetime import datetime
 from pathlib import Path
 from typing import Dict
+from urllib.parse import urlparse
 
 import git
-from git import NULL_TREE, GitCommandError
+from git import NULL_TREE, Commit, GitCommandError
 from pkg_resources import resource_filename
 
 from renku.core import errors
@@ -38,9 +41,11 @@ from renku.core.management.migrate import migrate
 from renku.core.management.repository import RepositoryApiMixin
 from renku.core.models.entities import Entity
 from renku.core.models.jsonld import load_yaml
-from renku.core.models.provenance.activities import Activity as ActivityRun
+from renku.core.models.provenance.activities import Activity
 from renku.core.models.provenance.activity import ActivityCollection
 from renku.core.models.provenance.provenance_graph import ProvenanceGraph
+from renku.core.models.workflow.dependency_graph import DependencyGraph
+from renku.core.models.workflow.plan import Plan
 from renku.core.models.workflow.run import Run
 from renku.core.utils import communication
 from renku.core.utils.contexts import measure
@@ -64,7 +69,7 @@ def generate_graph():
 def _generate_graph(client, force=False):
     """Generate graph and dataset provenance metadata."""
 
-    def process_workflows(commit, provenance_graph):
+    def process_workflows(commit: Commit, provenance_graph: ProvenanceGraph):
         for file_ in commit.diff(commit.parents or NULL_TREE, paths=f"{client.workflow_path}/*.yaml"):
             # Ignore deleted files (they appear as ADDED in this backwards diff)
             if file_.change_type == "A":
@@ -79,8 +84,8 @@ def _generate_graph(client, force=False):
                 communication.warn(f"Workflow file does not exists: '{path}'")
                 continue
 
-            workflow = ActivityRun.from_yaml(path=path, client=client)
-            activity_collection = ActivityCollection.from_activity_run(workflow, client.dependency_graph, client)
+            workflow = Activity.from_yaml(path=path, client=client)
+            activity_collection = ActivityCollection.from_activity(workflow, client.dependency_graph, client)
 
             provenance_graph.add(activity_collection)
 
@@ -364,7 +369,7 @@ _dot_debug = functools.partial(_dot, debug=True)
 
 def _json_ld(rdf_graph):
     """Format graph as JSON-LD."""
-    data = rdf_graph.serialize(format="json-ld").decode("utf-8")
+    data = rdf_graph.serialize(format="json-ld")
     print(data)
 
 
@@ -452,3 +457,49 @@ def _add_to_dataset(
     except (FileNotFoundError, git.exc.NoSuchPathError) as e:
         message = "\n\t".join(urls)
         raise errors.ParameterError(f"Could not find paths/URLs: \n\t{message}") from e
+
+
+def remove_workflow():
+    """Return a command for removing workflow."""
+    command = Command().command(_remove_workflow).lock_project()
+    return command.require_migration().with_commit(commit_only=GRAPH_METADATA_PATHS)
+
+
+def _remove_workflow(client, name: str, force: bool):
+    """Remove the given workflow."""
+    now = datetime.utcnow()
+    # TODO: refactor this once we switch to Database
+    provenance_graph = ProvenanceGraph.from_json(client.provenance_graph_path)
+    pg_workflows = unique_workflow(provenance_graph)
+
+    not_found_text = f'The specified workflow is "{name}" is not an active workflow.'
+    plan = None
+    parse_result = urlparse(name)
+    if parse_result.scheme:
+        plan = next(filter(lambda x: x.id == name, pg_workflows.values()), None)
+    if not plan and name not in pg_workflows:
+        raise errors.ParameterError(not_found_text)
+
+    if not force:
+        prompt_text = f'You are about to remove the following workflow "{name}".' + "\n" + "\nDo you wish to continue?"
+        communication.confirm(prompt_text, abort=True, warning=True)
+
+    plan = plan or pg_workflows[name]
+    plan.invalidated_at = now
+    dependency_graph = DependencyGraph.from_json(client.dependency_graph_path)
+    for p in dependency_graph.plans:
+        if p.id == plan.id:
+            p.invalidated_at = now
+
+    dependency_graph.to_json()
+    provenance_graph.to_json()
+
+
+def unique_workflow(provenance_graph: ProvenanceGraph) -> Dict[str, Plan]:
+    """Map of unique plans in the provenance graph indexed by name."""
+    workflows = dict()
+    for activity in provenance_graph.activities:
+        plan = activity.association.plan
+        if plan.invalidated_at is None and plan.name not in workflows:
+            workflows[plan.name] = plan
+    return workflows
