@@ -90,7 +90,7 @@ class Entity(CommitMixin):
     """Represent a data value or item."""
 
     _parent = attr.ib(
-        default=None, kw_only=True, converter=lambda value: weakref.ref(value) if value is not None else None,
+        default=None, kw_only=True, converter=lambda value: weakref.ref(value) if value is not None else None
     )
 
     checksum = attr.ib(default=None, kw_only=True, type=str)
@@ -101,11 +101,11 @@ class Entity(CommitMixin):
         if find_previous:
             revision = client.find_previous_commit(path, revision=revision)
 
-        client, commit, path = client.resolve_in_submodules(revision, path,)
+        client, commit, path = client.resolve_in_submodules(revision, path)
 
         path_ = client.path / path
         if path != "." and path_.is_dir():
-            entity = Collection(client=client, commit=commit, path=path, members=[], parent=parent,)
+            entity = Collection(client=client, commit=commit, path=path, members=[], parent=parent)
 
             files_in_commit = commit.stats.files
 
@@ -179,7 +179,7 @@ class Collection(Entity):
                 continue  # ignore empty directories in Git repository
             cls = Collection if path.is_dir() else Entity
             members.append(
-                cls(commit=self.commit, client=self.client, path=str(path.relative_to(self.client.path)), parent=self,)
+                cls(commit=self.commit, client=self.client, path=str(path.relative_to(self.client.path)), parent=self)
             )
         return members
 
@@ -267,5 +267,6 @@ def generate_file_id(client, hexsha, path):
         host = client.remote.get("host") or host
     host = os.environ.get("RENKU_DOMAIN") or host
 
+    # TODO: Use plural name for entity id: /blob/ -> /blobs/
     # always set the id by the identifier
     return urljoin(f"https://{host}", pathlib.posixpath.join(f"/blob/{hexsha}/{quote(str(path))}"))
