@@ -16,7 +16,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 """Renku service datasets view."""
-from flask import Blueprint, request
+from flask import request
 
 from renku.service.config import SERVICE_PREFIX
 from renku.service.controllers.datasets_add_file import DatasetsAddFileCtrl
@@ -27,6 +27,7 @@ from renku.service.controllers.datasets_import import DatasetsImportCtrl
 from renku.service.controllers.datasets_list import DatasetsListCtrl
 from renku.service.controllers.datasets_remove import DatasetsRemoveCtrl
 from renku.service.controllers.datasets_unlink import DatasetsUnlinkCtrl
+from renku.service.views.api_versions import V0_9, VersionedBlueprint
 from renku.service.views.decorators import (
     accepts_json,
     handle_common_except,
@@ -36,10 +37,10 @@ from renku.service.views.decorators import (
 )
 
 DATASET_BLUEPRINT_TAG = "datasets"
-dataset_blueprint = Blueprint(DATASET_BLUEPRINT_TAG, __name__, url_prefix=SERVICE_PREFIX)
+dataset_blueprint = VersionedBlueprint(DATASET_BLUEPRINT_TAG, __name__, url_prefix=SERVICE_PREFIX)
 
 
-@dataset_blueprint.route("/datasets.list", methods=["GET"], provide_automatic_options=False)
+@dataset_blueprint.route("/datasets.list", methods=["GET"], provide_automatic_options=False, versions=[V0_9])
 @handle_common_except
 @requires_cache
 @optional_identity
@@ -65,7 +66,7 @@ def list_datasets_view(user_data, cache):
     return DatasetsListCtrl(cache, user_data, dict(request.args)).to_response()
 
 
-@dataset_blueprint.route("/datasets.files_list", methods=["GET"], provide_automatic_options=False)
+@dataset_blueprint.route("/datasets.files_list", methods=["GET"], provide_automatic_options=False, versions=[V0_9])
 @handle_common_except
 @requires_cache
 @optional_identity
@@ -91,7 +92,7 @@ def list_dataset_files_view(user_data, cache):
     return DatasetsFilesListCtrl(cache, user_data, dict(request.args)).to_response()
 
 
-@dataset_blueprint.route("/datasets.add", methods=["POST"], provide_automatic_options=False)
+@dataset_blueprint.route("/datasets.add", methods=["POST"], provide_automatic_options=False, versions=[V0_9])
 @handle_common_except
 @accepts_json
 @requires_cache
@@ -119,7 +120,7 @@ def add_file_to_dataset_view(user_data, cache):
     return DatasetsAddFileCtrl(cache, user_data, dict(request.json)).to_response()
 
 
-@dataset_blueprint.route("/datasets.create", methods=["POST"], provide_automatic_options=False)
+@dataset_blueprint.route("/datasets.create", methods=["POST"], provide_automatic_options=False, versions=[V0_9])
 @handle_common_except
 @accepts_json
 @requires_cache
@@ -147,7 +148,7 @@ def create_dataset_view(user_data, cache):
     return DatasetsCreateCtrl(cache, user_data, dict(request.json)).to_response()
 
 
-@dataset_blueprint.route("/datasets.remove", methods=["POST"], provide_automatic_options=False)
+@dataset_blueprint.route("/datasets.remove", methods=["POST"], provide_automatic_options=False, versions=[V0_9])
 @handle_common_except
 @accepts_json
 @requires_cache
@@ -175,7 +176,7 @@ def remove_dataset_view(user_data, cache):
     return DatasetsRemoveCtrl(cache, user_data, dict(request.json)).to_response()
 
 
-@dataset_blueprint.route("/datasets.import", methods=["POST"], provide_automatic_options=False)
+@dataset_blueprint.route("/datasets.import", methods=["POST"], provide_automatic_options=False, versions=[V0_9])
 @handle_common_except
 @accepts_json
 @requires_cache
@@ -203,7 +204,7 @@ def import_dataset_view(user_data, cache):
     return DatasetsImportCtrl(cache, user_data, dict(request.json)).to_response()
 
 
-@dataset_blueprint.route("/datasets.edit", methods=["POST"], provide_automatic_options=False)
+@dataset_blueprint.route("/datasets.edit", methods=["POST"], provide_automatic_options=False, versions=[V0_9])
 @handle_common_except
 @accepts_json
 @requires_cache
@@ -231,7 +232,7 @@ def edit_dataset_view(user_data, cache):
     return DatasetsEditCtrl(cache, user_data, dict(request.json)).to_response()
 
 
-@dataset_blueprint.route("/datasets.unlink", methods=["POST"], provide_automatic_options=False)
+@dataset_blueprint.route("/datasets.unlink", methods=["POST"], provide_automatic_options=False, versions=[V0_9])
 @handle_common_except
 @accepts_json
 @requires_cache
